pub struct StreamPlan {
pub to_load: Vec<usize>,
pub to_evict: Vec<usize>,
}Expand description
The load / evict decisions produced by one StreamPlanner::plan call.
Fields
to_load: Vec<usize>Item ids whose background load should be dispatched this frame.
to_evict: Vec<usize>Item ids that should be evicted from the GPU this frame.