pub fn widest_line_width(content: &str, font: &LoadedFont, scale: f32) -> f32Expand description
Width of the widest line of content in scaled pixels: what a label’s
background box and its centre / right alignment are both sized against.
pub fn widest_line_width(content: &str, font: &LoadedFont, scale: f32) -> f32Width of the widest line of content in scaled pixels: what a label’s
background box and its centre / right alignment are both sized against.