pub fn text_advance_width(content: &str, font: &LoadedFont, scale: f32) -> f32Expand description
Advance width of content in scaled pixels for the given font, for placing a
caret or sizing a field’s text. Newlines carry no advance.
pub fn text_advance_width(content: &str, font: &LoadedFont, scale: f32) -> f32Advance width of content in scaled pixels for the given font, for placing a
caret or sizing a field’s text. Newlines carry no advance.